    function pp = calc_fcprob( bayesSpatial, contrast_cell)

% CALC_CONTRASTS calculate the contrasts based on the Bayes Spatial Model
% Usage: [cont_sim, pp, post_sim1 ] = calc_contrasts(bayesSpatial,contrast_cell)
% Input: 
%       bayesSpatial: Bayes model parameter learned from MCMC with Gibbs sampling;
%       contrast_cell: contrast set up from design matrix;
% Output: 
%       cont_sim: contrast simulation on region and voxel level;
%       pp: posterior probability;
%       post_sim1: posterior simulation; 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Lijun Zhang, Ph.D                        %
% Center for Biomedical Imaging Statistics (CBIS)  %
% Dept. of Biostatistics and Bioinformatics        %
% Emory University                                 %
% Atlanta, GA, 30322                               %
% Email: l.zhang@emory.edu                         %
% http://www.sph.emory.edu/bios/CBIS/about.html    %
% Jan, 2009, Last revision: Dec. 1, 2011           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     
post_sim1 = bayesSpatial.PostSim1;
post_sim2 = bayesSpatial.PostSim2; 

contrasts = contrast_cell{1,2};

% voxel estimates
 cont_sim.voxel = 0;
 for ii=1:size(contrasts, 2)
     cont_sim.voxel = cont_sim.voxel  + contrasts(ii) * post_sim2(ii).mu;
 end


% regional - use theta
cont_sim.regional = 0;
for ii=1:size(contrasts, 2)
    cont_sim.regional = cont_sim.regional  + contrasts(ii) * post_sim1(ii).theta;
end

% BAYES FACTORS - posterior odds vs prior odds...
%-------- mu -------------%
% probability that contrast is greater than zero, and divides
% by probability that contrast is less than zero
cont_sim.bf_voxel = sum(cont_sim.voxel >= 0,2)./max(1e-4,sum(cont_sim.voxel < 0,2));

cont_sim.bf_regional = sum(cont_sim.regional >= 0,2)./max(1e-4,sum(cont_sim.regional < 0,2));


% CONTRAST POSTERIOR PROBABILITIES OF Ho: theta>=0 vs H1: theta<0
M1 = size(cont_sim.voxel, 2);
pp.voxel = sum(cont_sim.voxel >= 0,2)./M1;

M2 = size(cont_sim.regional,2);
pp.regional = sum(cont_sim.regional >= 0,2)./M2;
