function [color_map, combinedImg, ppmap] ...
		 = change_color_map(handles, colorindex, cbarminmax)

%   Part of this file is copied and modified under GNU license from
%   jimmy (jimmy@rotman-baycrest.on.ca)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Modified by: Lijun Zhang, Ph.D                   %
% Center for Biomedical Imaging Statistics (CBIS)  %
% Dept. of Biostatistics and Bioinformatics        %
% Emory University                                 %
% Atlanta, GA, 30322                               %
% Email: l.zhang@emory.edu                         %
% http://www.sph.emory.edu/bios/CBIS/about.html    %
% Jan, 2009, Last revision: Jan 25, 2010           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%     
     
%    custom_color_map = [];

   if ~exist('colorindex', 'var')
      colorindex = get(handles.colorMapPop,'value');
   end

   if ~exist('cbarminmax', 'var')
      cbarminmax = handles.clim;
   end

   if isfield(handles, 'highcolor') && ~isempty(handles.highcolor)
      highcolor = handles.highcolor;
      num_highcolor = size(highcolor,1);
   else
      highcolor = [];
      num_highcolor = 0;
   end

%   if isfield(nii_view, 'colorlevel') & ~isempty(nii_view.colorlevel)
   if handles.colorlevel < 256
      num_color = handles.colorlevel;
   else
      num_color = 255 - num_highcolor;
   end

   contrast = [];

   if colorindex == 5					% for gray
        contrast = (num_color-1)*(handles.contrast-1)/255+1;
        contrast = ceil(contrast);      
   elseif colorindex == 1				% for bipolar
        contrast = handles.contrast;
   end

%    if isfield(handles,'color_map') && ~isempty(handles.color_map)
%       color_map = handles.color_map;
%       custom_color_map = color_map;
%    elseif colorindex == 1
%       [f p] = uigetfile('*.txt', 'Input colormap text file');
% 
%       if p==0
%          colorindex = handles.colorIndex;
%          set(handles.colorMapPop,'value',colorindex);
%          return; 
%       end;
% 
%       try
%          custom_color_map = load(fullfile(p,f));
%          loadfail = 0;
%       catch
%          loadfail = 1;
%       end
% 
%       if loadfail | isempty(custom_color_map) | size(custom_color_map,2)~=3 ...
% 	| min(custom_color_map(:)) < 0 | max(custom_color_map(:)) > 1 
% 
%          msg = 'Colormap should be a Mx3 matrix with value between 0 and 1';
%          msgbox(msg,'Error in colormap file');
%          colorindex = nii_view.colorindex;
%          set(nii_view.handles.colorindex,'value',colorindex);
%          return;         
%       end
% 
%       color_map = custom_color_map;
%       nii_view.color_map = color_map;
%    end

   

   switch colorindex
   case {1}
      color_map = bipolar(num_color, double(cbarminmax(1)), double(cbarminmax(2)), contrast);
   case {2}
      color_map = bone(num_color);
   case {3}
      color_map = cool(num_color);
   case {4}
      color_map = copper(num_color);      
   case {5}
      color_map = gray(num_color - contrast + 1);
   case {6}
      color_map = hot(num_color);     
      highcolor = gray(num_highcolor);
   case {7}
      color_map = jet(num_color); 
      highcolor = gray(num_highcolor);
   case {8}
      color_map = pink(num_color);
   end

   if colorindex == 5
      color_map = [zeros(contrast,3); color_map(2:end,:)];
   end

%    if get(nii_view.handles.neg_color,'value') & isempty(highcolor)
%       color_map = flipud(color_map);
%    elseif get(nii_view.handles.neg_color,'value') & ~isempty(highcolor)
%       highcolor = flipud(highcolor);
%    end

   color_map = brighten(color_map, handles.brightness);

   color_map = [color_map; zeros(1, 3); highcolor];

   %set(handles.figure1, 'Colormap', color_map);
   if handles.roi_voxel==0
        thresholded_functmap = ( handles.region_ppmap>=handles.threshold) .* handles.region_ppmap; %%%% Threshold region level
        ppmap = handles.region_ppmap;
   else
        thresholded_functmap = ( handles.voxel_ppmap>=handles.threshold) .* handles.voxel_ppmap; %%%% Threshold voxel level 
        ppmap = handles.voxel_ppmap;
   end
   combinedImg = overlay_w_transparency(uint16(handles.scaledImg), uint16(handles.scaledRegPP), thresholded_functmap, handles.opcity, color_map);

   return;					% change_colormap