function handles = get_pos(command)

% GET_POS: get current cursor positon, and display data information in the
% activity map display GUI.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Lijun Zhang, Ph.D                        %
% Center for Biomedical Imaging Statistics (CBIS)  %
% Dept. of Biostatistics and Bioinformatics        %
% Emory University                                 %
% Atlanta, GA, 30322                               %
% Email: l.zhang@emory.edu                         %
% http://www.sph.emory.edu/bios/CBIS/about.html    %
% Jan, 2009, Last revision: Dec. 1, 2011           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

handles = guidata(gcbf);
cp = get(get(gcbf,'CurrentAxes'),'CurrentPoint');
mri = handles.mri_struct;
[sagDim, corDim, axiDim] = size(mri.img);
coordindex = get(handles.axesUnit,'Value');

pp = handles.roi_voxel;
switch command
    case 'sag'
        cor = round(cp(1,1));
        axi = round(cp(1,2)); 
        if axi>axiDim
            axi = axiDim;
        elseif axi <1
            axi = 1;
        end
        if cor > corDim
            cor = corDim;
        elseif cor <1
            cor = 1;
        end
        handles.cor = cor;
        handles.axi = axi;
        
        set(handles.sagittal_xline,'Ydata',[axi axi]);
        set(handles.sagittal_yline,'Xdata',[cor cor]);
        set(handles.coronal_xline,'Ydata',[axi axi]);
        set(handles.axial_xline,'Ydata',[cor cor]);
        
        for cl = 1:3
            Saxial(:, :, cl) = squeeze(handles.combinedImg(cl).combound(:, :, axi))';
            Scor(:, :, cl) = squeeze(handles.combinedImg(cl).combound(:, cor,:))';
        end
        set(handles.axial_image,'CData',Saxial);
        set(handles.coronal_image,'CData',Scor);
        %set(handles.axial_image,'CData',squeeze(mri.img(:,:,axi))');
        %set(handles.coronal_image,'CData',squeeze(mri.img(:,cor,:))');
        set(handles.AxiSlider,'Value',axi);
        set(handles.CorSlider,'Value',cor);
        if coordindex == 1,
            set(handles.crosshairPos, 'String', sprintf('%7.0d %7.0d %7.0d',handles.sag, cor, axi));
        elseif coordindex == 2,
            cor_mm = (cor-handles.origin(2))*handles.pixdim(2);
            axi_mm = (axi-handles.origin(3))*handles.pixdim(3);    
            set(handles.crosshairPos, 'String', sprintf('%7.1f %7.1f %7.1f',handles.sag, cor_mm, axi_mm));
        end 
        
        % if pp == 0
        %     set(handles.crosshairVal,'String',...
        %         sprintf('Val:%5.0d, PP:%4.2f',mri.img(handles.sag, cor, axi),handles.region_ppmap(handles.sag, cor, axi)));
        % elseif pp == 1;
        %     set(handles.crosshairVal,'String',...
        %         sprintf('Val:%5.0d, PP:%4.2f',mri.img(handles.sag, cor, axi),handles.voxel_ppmap(handles.sag, cor, axi)));
        % end
    case 'cor'
        sag = round(cp(2,1));
        axi = round(cp(2,2));
        if axi>axiDim
            axi = axiDim;
        elseif axi <1
            axi = 1;
        end
        if sag > sagDim
            sag = sagDim;
        elseif sag <1
            sag = 1;
        end
        handles.sag = sag;
        handles.axi = axi;
        
        set(handles.coronal_xline,'Ydata',[axi axi]);
        set(handles.coronal_yline,'Xdata',[sag sag]);
        set(handles.axial_yline,'Xdata',[sag sag]);
        set(handles.sagittal_xline,'Ydata',[axi axi]); 
        for cl = 1:3
            Saxial(:, :, cl) = squeeze(handles.combinedImg(cl).combound(:, :, axi))';
            Ssag(:, :, cl) = squeeze(handles.combinedImg(cl).combound(sag, :, :))';
        end
        set(handles.axial_image,'CData',Saxial);
        set(handles.sagittal_image,'CData',Ssag);
        
        %set(handles.axial_image,'CData',squeeze(mri.img(:,:,axi))');
        %set(handles.sagittal_image,'CData',squeeze(mri.img(sag,:,:))');
        set(handles.AxiSlider,'Value',axi);
        set(handles.SagSlider,'Value',sag); 
        
        if coordindex == 1,
            set(handles.crosshairPos, 'String', sprintf('%7.0d %7.0d %7.0d',sag, handles.cor, axi));
        elseif coordindex == 2,
            sag_mm = (sag-handles.origin(1))*handles.pixdim(1);
            axi_mm = (axi-handles.origin(3))*handles.pixdim(3);    
            set(handles.crosshairPos, 'String', sprintf('%7.1f %7.1f %7.1f',sag_mm, handles.cor, axi_mm));
        end 
        %set(handles.crosshairVal,'String',mri.img(sag, handles.cor, axi));
        % if pp == 0
        %     set(handles.crosshairVal,'String',...
        %         sprintf('Val:%5.0d, PP:%4.2f',mri.img(sag, handles.cor, axi),handles.region_ppmap(sag, handles.cor, axi)));
        % elseif pp == 1;
        %     set(handles.crosshairVal,'String',...
        %         sprintf('Val:%5.0d, PP:%4.2f',mri.img(sag, handles.cor, axi),handles.voxel_ppmap(sag, handles.cor, axi)));
        % end
    case 'axi'
        sag = round(cp(2,1));
        cor = round(cp(2,2));
        if cor>corDim
            cor = corDim;
        elseif cor <1
            cor = 1;    
        end
        if sag > sagDim
            sag = sagDim;
        elseif sag <1
            sag = 1;    
        end
        handles.sag = sag;
        handles.cor = cor;
        
        set(handles.axial_yline,'Xdata',[sag sag]);
        set(handles.axial_xline,'Ydata',[cor cor]);
        set(handles.coronal_yline,'Xdata',[sag sag]);
        set(handles.sagittal_yline,'Xdata',[cor cor]); 
        
        for cl = 1:3
            Scor(:, :, cl) = squeeze(handles.combinedImg(cl).combound(:, cor,:))';
            Ssag(:, :, cl) = squeeze(handles.combinedImg(cl).combound(sag, :, :))';
        end
        set(handles.coronal_image,'CData',Scor);
        set(handles.sagittal_image,'CData',Ssag);
        %set(handles.sagittal_image,'CData',squeeze(mri.img(sag,:,:))');
        %set(handles.coronal_image, 'CData',squeeze(mri.img(:,cor,:))');
        set(handles.SagSlider,'Value',sag);
        set(handles.CorSlider,'Value',cor);
        if coordindex == 1,
            set(handles.crosshairPos, 'String', sprintf('%7.0d %7.0d %7.0d',sag, cor, handles.axi));
        elseif coordindex == 2,
            sag_mm = (sag-handles.origin(1))*handles.pixdim(1);
            cor_mm = (cor-handles.origin(2))*handles.pixdim(2);    
            set(handles.crosshairPos, 'String', sprintf('%7.1f %7.1f %7.1f',sag_mm, cor_mm, handles.axi));
        end 
        %set(handles.crosshairVal,'String',mri.img(sag, cor, handles.axi));
        % if pp == 0
        %     set(handles.crosshairVal,'String',...
        %         sprintf('Val:%5.0d, PP:%4.2f',mri.img(sag, cor, handles.axi),handles.region_ppmap(sag, cor, handles.axi)));
        % elseif pp == 1;
        %     set(handles.crosshairVal,'String',...
        %         sprintf('Val:%5.0d, PP:%4.2f',mri.img(sag, cor, handles.axi),handles.voxel_ppmap(sag, cor, handles.axi)));
        % end
        
end

if pp == 0
    set(handles.crosshairVal,'String',...
        sprintf('PP: %4.2f',...%mri.img(handles.sag, handles.cor, handles.axi),...
                handles.region_ppmap(handles.sag, handles.cor, handles.axi)));
elseif pp == 1;
    set(handles.crosshairVal,'String',...
        sprintf('PP: %4.2f',...%mri.img(handles.sag, handles.cor, handles.axi),...
                handles.voxel_ppmap(handles.sag, handles.cor, handles.axi)));
end

valId = cell2mat(handles.total_region_name(:, 1));
curIdVal = handles.region_struct.img(handles.sag, handles.cor, handles.axi);

curIdPos = find(ismember(valId, curIdVal)); 
if curIdPos
    set(handles.curInfo, 'ForegroundColor','g',...
        'FontSize', 10, 'HorizontalAlignment', 'left', 'String', ...
         sprintf('Current crosshair is located in the region: %s', ...
                  handles.total_region_name{curIdPos, 2}));
else
    set(handles.curInfo, 'String', '');
end

talsag = (handles.sag-handles.origin(1))*handles.pixdim(1);
talcor = (handles.cor-handles.origin(2))*handles.pixdim(2);
talaxi = (handles.axi-handles.origin(3))*handles.pixdim(3); 
outpoints = round(mni2tal([talsag, talcor, talaxi]));

set(handles.talairachText,'ForegroundColor','r',...
    'FontSize', 10, 'HorizontalAlignment', 'left', 'String',sprintf('Current Crosshair Talairach Coordinates: %s, %s, %s',num2str(outpoints(1)), num2str(outpoints(2)), num2str(outpoints(3))));

guidata(gcbf, handles);
return