function x_labs = design_matrix(main_fig)

% DESIGN_MATRIX calculate the contrast based on the patient data
% by Sanjay Agravat, Emory University
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Modified by: Lijun Zhang, Ph.D                   %
% Center for Biomedical Imaging Statistics (CBIS)  %
% Dept. of Biostatistics and Bioinformatics        %
% Emory University                                 %
% Atlanta, GA, 30322                               %
% Email: l.zhang@emory.edu                         %
% http://www.sph.emory.edu/bios/CBIS/about.html    %
% Jan, 2009, Last revision: Jan 25, 2010           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% Use system background color for GUI components
panelColor = get(0,'DefaultUicontrolBackgroundColor');
handles.main = main_fig;

mainHandles = guidata(main_fig);
data = mainHandles.dataInfo;
X_GSS = mainHandles.expdata;
X_Covariates = mainHandles.expdata_cov;
X=[X_GSS, X_Covariates];
headInfo = mainHandles.headInfo;

column = length(headInfo);

checkLegend = exist('results/legend.mat');
if checkLegend > 0    
    l = load(fullfile('results','legend')); 
    if ~isequal(size(X, 2),numel(l.legend.groups)*numel(l.legend.sessions)*numel(l.legend.stimuli)+column-5)
        checkLegend = 0;
        clear l
    end
end

%% Global Variables
row1Y = 5;
row2Y = 2;

buttonWidth = 18;
numMatrixes = ' 1';
graphTitle = 'Contrast Matrix 1';
%contrasts = [1 1 1 1];

colNum = size(X, 2);
contrasts = ones(1, colNum);
%-- set up the design matrix --------------------------------

groups=unique(data{3});
no_groups=numel(groups);
    
sessions=unique(data{4});
no_sessions=numel(sessions);
    
stimuli=unique(data{5});
no_stimuli=numel(stimuli);

x_labels={};        % labels for the design matrix display
legendId = [];

for g=1:no_groups;
    for s=1:no_sessions;
        for t=1:no_stimuli;
            x_labels{g, s, t}=strcat('(', groups(g), ',', sessions(s), ',', stimuli(t),')');
            pos=sub2ind([no_stimuli no_sessions no_groups], t, s, g); 
            labels(pos)=x_labels(g, s, t);
            legendId.group(pos) = g;
            legendId.session(pos) = s;
            legendId.stimulus(pos) = t;
        end
    end;
end;

for i=1:g*s*t;
    x_labs(i)=labels{i};  % finally, x axis tick labels
end;
for i = 1:column-5
    x_labs(end+1)=headInfo(i+5);
end

Z = X;

%% ------------ Callback Functions ---------------

% Figure resize function
function figResize(src,evt)
    fpos = get(f,'Position');
    set(botPanel,'Position',...
        [1/20 1/20 fpos(3)-.1 fpos(4)*8/35])
    set(rightPanel,'Position',...
        [fpos(3)*85/120 fpos(4)*8/35 fpos(3)*35/120 fpos(4)*27/35])
    set(centerPanel,'Position',...
        [1/20 fpos(4)*8/35 fpos(3)*85/120 fpos(4)*27/35]);
end
    
% Bottom panel resize function
function botPanelResize(src, evt)
    
    bpos = get(botPanel,'Position');
    set(contrastsTextFld,'Position',...
        [bpos(3)*30/120 bpos(4)*row1Y/8 bpos(3)*newDesignMatrixPos(3)/160 newContrastPos(4)])
    set(updateContrastsButton,'Position',...
        [bpos(3)*10/120 bpos(4)*row1Y/8 bpos(3)*buttonWidth/120 2])
    set(newConstrastsButton,'Position',...
        [bpos(3) * 1/160 bpos(4) * 1/10 bpos(3) * buttonWidth/160 2])
    set(designMatrixNameButton,'Position',...
        [bpos(3)*10/120 bpos(4)*row2Y/8 bpos(3)*buttonWidth/120 2])
    set(newDesignMatrixTextFld,'Position',...        
        [bpos(3)*newDesignMatrixPos(1)/160 bpos(4)* newDesignMatrixPos(2)/10 bpos(3)* newDesignMatrixPos(3)/160 newDesignMatrixPos(4)])        
    set(newDesignMatrixText,'Position',...        
        [bpos(3)*newDesignMatrixTextPos(1)/160 bpos(4)* newDesignMatrixTextPos(2)/10 bpos(3)* newDesignMatrixTextPos(3)/160 2])        
    set(newContrastTextFld,'Position',...        
        [bpos(3)*newContrastPos(1)/160 bpos(4)* newContrastPos(2)/10 bpos(3)* newContrastPos(3)/160 newContrastPos(4)])        
%     set(botRightPanel,'Position',...        
%         [bpos(3)*botRightPanelPos(1)/160 bpos(4)* botRightPanelPos(2)/10 bpos(3)* botRightPanelPos(3)/botPanelPos(3) botRightPanelPos(4)])        
    set(botRightPanel,'Position',...        
        [bpos(3)*botRightPanelPos(1)/160 bpos(4)* botRightPanelPos(2)/10 bpos(3)* botRightPanelPos(3)/botPanelPos(3) bpos(4)-0.8])        

    set(ContrastText,'Position',...        
        [bpos(3)*contrastTextPos(1)/160 bpos(4)* contrastTextPos(2)/10 bpos(3)* contrastTextPos(3)/160 contrastTextPos(4)])        
    
    set(designMatrixTextFld,'Position',...
        [bpos(3)*30/120 bpos(4)*row2Y/8 bpos(3)*newDesignMatrixPos(3)/160 newDesignMatrixPos(4)])    
end

% Right panel resize function
function rightPanelResize(src,evt)
    rpos = get(rightPanel,'Position');
    set(listBox,'Position',...
        [rpos(3)*listBoxPos(1)/32 rpos(4)*listBoxPos(2)/27 rpos(3)*listBoxPos(3)/32 rpos(4)*listBoxPos(4)/27]);
    set(listBoxLabel,'Position',...
        [rpos(3)*4/32 rpos(4)*24/27 rpos(3)*24/32 rpos(4)*2/27]);
    set(executeButton,'Position',...
        [rpos(3)*executeButtonPos(1)/50 rpos(4)*executeButtonPos(2)/40 rpos(3)*executeButtonPos(3)/32 rpos(4)*executeButtonPos(4)/32]);
    set(removeButton,'Position',...
        [rpos(3)*removeButtonPos(1)/50 rpos(4)*removeButtonPos(2)/40 rpos(3)*removeButtonPos(3)/32 rpos(4)*removeButtonPos(4)/32]);
    set(createLegendButton,'Position',...
        [rpos(3)*createLegendButtonPos(1)/50 rpos(4)*createLegendButtonPos(2)/40 rpos(3)*createLegendButtonPos(3)/47 rpos(4)*createLegendButtonPos(4)/32]);

end

%% Callback for list box
  function listBoxCallback(src,evt)
        vars = get(listBox,'String');
        var_index = get(listBox,'Value');
        set(designMatrixTextFld, 'String', vars{var_index});
        contrasts = matrix_contrasts{var_index,2};
        updatePlot(contrasts);
        set(contrastsTextFld, 'String', num2str(contrasts));
        axes(a)
        title(vars{var_index});    
  end % listBoxCallback

%% updateDesignMatrixNameCallback
  function updateDesignMatrixNameCallback(src,evt)
        % Load workspace vars into list box
        graphTitle = get(designMatrixTextFld, 'String');
        vars = get(listBox,'String');
        var_index = get(listBox,'Value');
        vars{var_index} = graphTitle;  
        
        matrix_contrasts{var_index, 1} = graphTitle;
        set(listBox, 'String', vars);
        title(graphTitle);
  end % listBoxCallback

%% Callback for plot button
    function updateContrastsButtonCallback(src,evt)
        % Get workspace variables
        contrasts = str2num(get(contrastsTextFld,'String'));  
        updatePlot(contrasts);

    end % updateContrastsButtonCallback
   
%% Callback for remove button    
function removeButtonCallback(src, evt)
        vars = get(listBox,'String');
        var_index = get(listBox,'Value');  
        if var_index == length(vars)
            if var_index == 1
                set(listBox,'Value', var_index);
            else
                set(listBox,'Value', var_index-1); 
            end
        end
        vars(var_index) = [];          
        matrix_contrasts(var_index, :) = [];        
        set(listBox, 'String', vars);        
end

%% Callback for execute button
function executeButtonCallback(src, evt)
    var_index = get(listBox,'Value');
    save(fullfile('results','matrix_contrasts'),'matrix_contrasts', 'var_index');
    save(fullfile('results','title_legend')','x_labels', 'x_labs');
    %mainHandles.title_legend = x_labs;
    %guidata(handles.main, handles.main);
    %main = handles.main;
    %mainHandles = guidata(main);
    switch (mainHandles.RegionMapType)
        case 'analyze'
            set(mainHandles.analyzeRegionsListbox, 'Enable', 'On');
            set(mainHandles.brodmannRegionsListbox, 'Enable', 'Off');

        case 'brodmann'
            set(mainHandles.brodmannRegionsListbox, 'Enable', 'On');
            set(mainHandles.analyzeRegionsListbox, 'Enable', 'Off');
    end

    set(mainHandles.addButton, 'Enable', 'On');
    set(mainHandles.removeButton, 'Enable', 'On');
%        set(mainHandles.contrastsButton, 'Visible', 'On');

    close(f);
end

%% Callback for hold state toggle button
    function newConstrastsButtonCallback(src,evt)
    
        name = get(newDesignMatrixTextFld, 'String');
        if ~isempty(name)
            vars = get(listBox,'String');

            [tempv, tempId] =intersect(vars, name);
            tempContrasts = str2num(get(newContrastTextFld,'String'));
            if isempty(tempId)            
                index = length(vars) + 1;   
                matrix_contrasts{index, 1} = name;
                matrix_contrasts{index, 2} = tempContrasts;
                vars{index} = name;                    
                set(listBox, 'String', vars);
            else
                ButtonName = questdlg('The name is already used, are you sure to overwrite the existed file?','!! Warning !!', 'Cancel', 'Yes','Cancel');
                switch ButtonName,
                    case 'Yes',
                        index = tempId;
                        matrix_contrasts{index, 1} = name;
                        matrix_contrasts{index, 2} = tempContrasts;
                        vars{index} = name;                    
                        set(listBox, 'String', vars);
                 end % switch

            end
        end
    
    end % newConstrastsButtonCallback

%% Callback for axes
    function createAxesCallback(src, evt)
        imagesc(Z);  
        colormap(vivid(64,[.25 .85],'rwb')); colorbar;        
        title('Contrast Matrix 1');
        set(gca,'XTick',[1:g*s*t+column-5],'XTickLabel',x_labs,'fontsize',8);
        
        axis on; ylabel('subjects','FontSize',8);
        xlabel('(group,session,stimulus)');            
    end

    function displayLegend()
        legendTextPos = [4 11 10 2];
        legendText = uicontrol(f,'Style','text','Units','characters',...
                'Position', legendTextPos,...
                'HorizontalAlignment', 'left', ...
                'String', 'Legend:',...
                'Parent', rightPanel ...
                );    

        groupTextPos = [6 9 38 2];
        groupsLabelText = '';
        for aa=1:size(l.legend.groups, 2)
          groupsLabelText = strcat(groupsLabelText, num2str(aa), ' <=> ', {' '}, l.legend.groups{aa}, {'; '}); 
        end
        groupText = uicontrol(f,'Style','text','Units','characters',...
                'Position', groupTextPos,...
                'HorizontalAlignment', 'left', ...
                'String', strcat('Group: ', groupsLabelText),...
                'Parent', rightPanel ...
                );    

        sessionsLabelText = '';
        for aa=1:size(l.legend.sessions, 2)
          sessionsLabelText = strcat(sessionsLabelText, num2str(aa), ' <=> ', {' '}, l.legend.sessions{aa}, {'; '}); 
        end
        sessionTextPos = [6 7 38 2];
        sessionText = uicontrol(f,'Style','text','Units','characters',...
                'Position', sessionTextPos,...
                'HorizontalAlignment', 'left', ...
                'String', strcat('Session: ', sessionsLabelText),...
                'Parent', rightPanel ...
                );    

        stimulusLabelText = '';
        for aa=1:size(l.legend.stimuli, 2)
          stimulusLabelText = strcat(stimulusLabelText, num2str(aa), ' <=> ', {' '}, l.legend.stimuli{aa}, {'; '}); 
        end    
        stimulusTextPos = [6 5 38 2];
        stimulusText = uicontrol(f,'Style','text','Units','characters',...
                'Position', stimulusTextPos,...
                'HorizontalAlignment', 'left', ...
                'String', strcat('Stimulus: ', stimulusLabelText),...
                'Parent', rightPanel ...
                );    

    end


    function createLegendGuiCallback(src, evt)
       legend = LegendGui(gcf, groups, sessions, stimuli);
       save(fullfile('results','legend.mat'),'legend');
       l = load(fullfile('results','legend.mat'));
       %l = load('results/legend');
       %set(src, 'Visible', 'off');
       displayLegend();
    end
%% helper method
    function updatePlot(contrasts)
        % Make the GUI axes current and create plot
        axes(a)
        Y = Z;
        %columns = size(Z,2);
        %rows = size(Z,1);
        [rows, columns] = size(Z);
        %m = ones(columns, rows)';
        m = ones(rows, columns);
        
        len = size(contrasts, 2);
        for jj=1:len
            m(:,jj) = contrasts(jj);        
        end
        X = m.*Y;
        
        var_index = get(listBox,'Value'); 
        vars = get(listBox,'String');        
        matrix_contrasts{var_index, 2} = contrasts;
        imagesc(X);  
        colormap(vivid(64,[.25 .85],'rwb')); colorbar
        %title(graphTitle);
        title(vars{var_index});
        
        set(gca,'XTick',[1:g*s*t+column-5],'XTickLabel',x_labs,'fontsize',8)
%         XTick = get(gca, 'XTick');
%         XTickLabel = get(gca, 'XTickLabel');
%         xticklabel_rotate_new(XTick, 30, XTickLabel);
        axis on; ylabel('subjects','FontSize',12);
        xlabel('(group,session,stimulus)');
    end

%% ------------ GUI layout ---------------

%% Set up the figure and matrix_contrastss
figurePos = [10 10 160 50];
f = figure('Units','characters',...
        'Position',figurePos,...
        'Color',panelColor,...
        'HandleVisibility','callback',...
        'IntegerHandle','off',...
        'Renderer','painters',...
        'Toolbar','figure',...
        'NumberTitle','off',...
        'Name','Contrast Matrix',...
        'ResizeFcn',@figResize);

%% Create the bottom uipanel
botPanelPos = [1/20 0.5 50 11];
botPanel = uipanel('BorderType','etchedin',...
    'BackgroundColor',panelColor,...
    'Units','characters',...
    'Position',botPanelPos,...
    'Parent',f,...
    'Title', 'Current Contrast',...
    'ResizeFcn',@botPanelResize);


%% Create the bottom uipanel
botRightPanelPos = [90 0.5 70 11];
botRightPanel = uipanel('BorderType','etchedin',...
    'BackgroundColor',panelColor,...
    'Units','characters',...
    'Position', botRightPanelPos,...
    'Parent',f,...
    'Title', 'New Contrast',...
    'ResizeFcn',@botPanelResize);



%% Create the right side panel
rightPanelPos = [88 8 32 27];
rightPanel = uipanel('bordertype','etchedin',...
    'BackgroundColor',panelColor,...
    'Units','characters',...
    'Position',rightPanelPos,...
    'Parent',f,...
    'ResizeFcn',@rightPanelResize);

%% Create the center panel
centerPanelPos = [1/20 8 88 27];
centerPanel = uipanel('bordertype','etchedin',...
    'Units','characters',...
    'Position', centerPanelPos,...
    'Parent',f);

%% Add an axes to the center panel
a = axes('parent',centerPanel, ...
          'CreateFcn', @createAxesCallback);

%% Add listbox and label
listBoxLabel = uicontrol(f,'Style','text','Units','characters',...
        'Position',[4 24 24 2],...
        'String','Contrast Matrices',...
        'BackgroundColor',panelColor,...
        'Parent',rightPanel);
listBoxPos = [4 15 24 10];
listBox = uicontrol(f,'Style','listbox','Units','characters',...
        'Position',listBoxPos,...
        'BackgroundColor','white',...
        'Max',10,'Min',1,...
        'Parent',rightPanel,...
        'Callback',@listBoxCallback);

createLegendButtonPos = [6 15 35 2];
createLegendButton = uicontrol(f,'Style','pushbutton','Units','characters',...
            'Position', createLegendButtonPos,...
            'String', 'Create New Legend',...
            'Parent', rightPanel,...
            'Callback', @createLegendGuiCallback);
        
if checkLegend > 0
    displayLegend();
% else
%     createLegendButtonPos = [8 12 20 2];
%     createLegendButton = uicontrol(f,'Style','pushbutton','Units','characters',...
%             'Position', createLegendButtonPos,...
%             'String', 'Create Legend',...
%             'Parent', rightPanel,...
%             'Callback', @createLegendGuiCallback);
end

removeButtonPos = [6 18 12 2];
removeButton = uicontrol(f,'Style','pushbutton','Units','characters',...
        'Position', removeButtonPos,...
        'String', 'Remove',...
        'Parent', rightPanel,...
        'Callback', @removeButtonCallback);
    
executeButtonPos = [24.6 18 12 2];
executeButton = uicontrol(f,'Style','pushbutton','Units','characters',...
        'Position', executeButtonPos,...
        'String', 'Done',...
        'BackgroundColor','Green',...
        'Parent', rightPanel,...
        'Callback', @executeButtonCallback);
    
  
    
    
%% Add uicontrols      
newDesignMatrixTextPos = [1 6 10 2];
newDesignMatrixText = uicontrol(f,'Style','text','Units','characters',...
        'Position', newDesignMatrixTextPos,...
        'String', 'Name',...
        'Parent', botRightPanel ...
        );

newDesignMatrixPos = [15 6.5 24 2];    
newDesignMatrixTextFld = uicontrol(f,'Style','edit','Units','characters',...
        'Position', newDesignMatrixPos,...
        'BackgroundColor', 'white',...
        'String', '',...
        'Parent', botRightPanel ...
        );
    
newContrastPos = [15 4 24 2];    
newContrastTextFld = uicontrol(f,'Style','edit','Units','characters',...
        'Position', newContrastPos,...
        'BackgroundColor', 'white',...
        'String', num2str(ones(1, colNum)), ... %'1 1 1 1',...
        'Parent', botRightPanel ...
        );

    
contrastTextPos = [1 3.5 10 2];
ContrastText = uicontrol(f,'Style','text','Units','characters',...
        'Position', contrastTextPos,...
        'String', 'Contrast',...
        'Parent', botRightPanel ...
        );

newConstrastsButton = uicontrol(f,'Style','pushbutton','Units','characters',...
        'Position', [1 1 buttonWidth 2],...
        'String', 'Create',...
        'Parent', botRightPanel,...
        'Callback', @newConstrastsButtonCallback);
    
    
updateContrastsButton = uicontrol(f,'Style','pushbutton','Units','characters',...
        'Position', [50 row1Y buttonWidth 2],...
        'String', 'Update Contrast',...
        'Parent', botPanel,...
        'Callback', @updateContrastsButtonCallback);

contrastsTextFld = uicontrol(f,'Style','edit','Units','characters',...
        'Position', [70 row1Y buttonWidth 2],...
        'String', num2str(ones(1, colNum)),...
        'BackgroundColor', 'white',...
        'Parent', botPanel ...
        );

designMatrixNameButton = uicontrol(f,'Style','pushbutton','Units','characters',...
        'Position', [50 row2Y buttonWidth 2],...
        'String', 'Update Name',...
        'Parent', botPanel,...
        'Callback', @updateDesignMatrixNameCallback);

designMatrixTextFld = uicontrol(f,'Style','edit','Units','characters',...
        'Position', [70 row2Y buttonWidth 2],...
        'BackgroundColor', 'white',...
        'String', strcat('Contrast Matrix ',numMatrixes),...
        'Parent', botPanel ...
        );

  
    
%% Initialize list box 
    check = exist('results/matrix_contrasts.mat');
    if check > 0
        %m = load('results/matrix_contrasts');     
        m = load(fullfile('results','matrix_contrasts'));  
        matrix_contrasts = m.matrix_contrasts;
        if size(matrix_contrasts{1,2}, 2)~=colNum
            clear matrix_contrasts
            matrix_contrasts{1,1} = graphTitle;
            matrix_contrasts{1,2} = ones(1, colNum);  
        end
    else
        matrix_contrasts{1,1} = graphTitle;
        matrix_contrasts{1,2} = ones(1, colNum);          
    end    
    
    
    len = size(matrix_contrasts, 1);    
    for ii=1:len
        vars{ii} = char(matrix_contrasts{ii,1});    
    end
    set(listBox, 'String', vars);
    
    contrasts = matrix_contrasts{1, 2}; 
    updatePlot(contrasts);
%    newConstrastsButtonCallback(newConstrastsButton,[])  
end % design_matrix


