function plot_contrasts_stmod2coc(cont_sim, pp, post_sim1, titleStr, regions, regionNames, btnType)

% PLOT_CONTRASTS_STMOD2COC: plot contrasts in the basic summary plot
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Lijun Zhang, Ph.D                        %
% Center for Biomedical Imaging Statistics (CBIS)  %
% Dept. of Biostatistics and Bioinformatics        %
% Emory University                                 %
% Atlanta, GA, 30322                               %
% Email: l.zhang@emory.edu                         %
% http://www.sph.emory.edu/bios/CBIS/about.html    %
% Jan, 2009, Last revision: Dec. 1, 2011           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin < 4
    save_plots=0;
end

%% Legend
%if btnType
    hh = figure;
    set(hh, 'Name', 'Region Legend', 'Color', 'White');
    tablePositionOrg = get(hh, 'position');
    tablePosition = tablePositionOrg;
    tableLength = length(regionNames)+1;    
    tablePosition(4) = tableLength*(tablePositionOrg(4)-80)/15+20;
    tablePosition(2) = 460 -  tablePosition(4)/2;
    set(hh, 'Position',  tablePosition);
%     position = get(hh, 'position')
%end

position = [10, 10, 540, tablePosition(4)-20];
uitable(hh, 'ColumnName', 'Selected Regions', 'ColumnWidth', {505}, 'Position', position, 'Data', regionNames);

%% Regional Posterior Means: fMRI contrast vs. region

load(fullfile('results', 'title_legend'));
if ~btnType
    clf(hh);
    set(hh, 'Position',  tablePositionOrg);
end

if btnType    
    f1 = figure();
    set(gcf, 'Name', strcat('Regional Posterior Means: fMRI contrast vs. region -- ', titleStr));
end
bar(mean(cont_sim.regional, 2)); 
%xticklabel_rotate([], 45,regions,'Fontsize',10);
title(['Region Estimate for ', titleStr]),xlabel('Region'), ylabel('fMRI Contrast Estimate');

%% Regional Posterior Probabilities
if btnType
    f2 = figure();
    set(gcf, 'Name', strcat('Regional Posterior Probabilities -- ', titleStr));
end

bar(pp.regional);
title(['Regional Posterior Probabilities for ', titleStr]);
refline(0,0.5);
%xticklabel_rotate([], 45,regions,'Fontsize',10); 
xlabel('Region'), ylabel('Probabilities');

%% Histogram of voxel-level Posterior Probabilities
if btnType
    f3 = figure();
    set(gcf, 'Name', strcat('Histogram of voxel-level Posterior Probabilities -- ', titleStr));
end
hist(pp.voxel, 30), title(['Voxel Posterior Probabilities for ', titleStr]); 
refline(0.85,0.0), xlim([0.1 1]), xlabel('prob'), ylabel('# of voxels')

corrvec=[post_sim1(:).rho]';

maxcorr=max(mean(corrvec));
%% Intra-regional Correlations, (Group, Session, Stimulus)
if btnType
    f4 = figure();
    set(gcf, 'Name', strcat('Intra-regional Correlations, (Group, Session, Stimulus), for ', titleStr));
end
    m = size(post_sim1, 2)/2;
    n = 2;
    for ii=1:size(post_sim1, 2)
        s = ['\rho ', x_labs{ii}]; 
        % region by correlation
        subplot(m, n, ii), bar(median(post_sim1(ii).rho,2)),ylim([0 min(1,maxcorr+.31)]),title(s), xlabel('Region'), ylabel('Correlation')
        % TODO: label each variable with text from user
    end
%% Inter-regional Correlations, (Group, Session, Stimulus)
if btnType
    f5 = figure();
    set(gcf, 'Name', strcat('Inter-regional Correlations, (Group, Session, Stimulus), for ', titleStr));
end
 dimensions = size(post_sim1, 2);
 for ii=1:dimensions
     L = sqrt(size(post_sim1(ii).iGamma,1));
     Gamma1 = inv(reshape(median(post_sim1(ii).iGamma,2),L,L));
     R1 = diag(diag(Gamma1).^-0.5) * Gamma1 * diag(diag(Gamma1).^-0.5);
     RThresh=R1.*(R1 >= 0.1);
     RThresh(RThresh==0)=NaN;
     
     conn_matrix{ii} = RThresh;
     s = ['R ', x_labs{ii}]; 
     subplot(m, n, ii), imagesc(RThresh,[-1 1]), axis image, title(s), colorbar('v')
     set(gca, 'Xtick', 1:length(regionNames), 'Ytick',1:length(regionNames));
 end
 

%save('data/conn_matrix');
end

