function [roi_ppmap]=plot_regional_pp_map_toolbox(pp,pp_thresh,regions,anat_map,save_plot)
% This function overlays regionsl posterior probabilities 
% over an anatomical brain
% Input: 
%   pp = structure w/ results, from the simulation output
%   pp_thresh = threshold for the pp 
%   region_list = txt file with the list of regions selected for analysis
%   (full file path)
%   anat_map = anatomical map (aal, Brodmann - full path)
% Output: 
%   roi_ppmap= 3D matrix w/ regional pp values

% Example use: 
% region_list='C:\Anatomical\Selected_regions_prepost_Brodmann.txt'
% anat_map='C:\ROI_MNI_V4.img';
% [roi_ppmap]=plot_regional_pp_map_toolbox(pp,0.2,region_list,anat_map,0)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Writen by: Gordana Derado, Ph.D, Emory Univ.     %
% Modified by: Lijun Zhang, Ph.D                   %
% Center for Biomedical Imaging Statistics (CBIS)  %
% Dept. of Biostatistics and Bioinformatics        %
% Emory University                                 %
% Atlanta, GA, 30322                               %
% Email: l.zhang@emory.edu                         %
% http://www.sph.emory.edu/bios/CBIS/about.html    %
% Jan, 2009, Last revision: Jan 25, 2010           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

ctr=37; %set axial center; for overlay function
if nargin<3
    save_plot=0;
end

G=size(regions,1);

% TODO: handle nifti and analyze
roi_struct=avw_img_read(anat_map);
roi_map=roi_struct.img;

% Following depends on the contrast
% ----------------- Patients versus Controls ------------------------------
roi_ppmap=zeros(size(roi_map));
for g=1:G
    % TODO: get find function from modified version
    locs=find(roi_map>=regions(g,1) & roi_map<=regions(g,2));

    
    %roi_ppmap_patsvsctls(locs)=pp.theta_trt_pat(g);
    roi_ppmap(locs)=pp.regional(g);
end

%imagesc(roi_ppmap(:,:,50)); axis image; colorbar
