function [voxel_ppmap]=plot_voxel_pp_map_toolbox(pp,pp_thresh,region_list,anat_map,brain_locs, glocs, mri_fn, save_plot)
% This function overlays voxel posterior probabilities 
% over the anatomical brain
% Input: 
%   pp = structure w/ results, from the simulation output
%   pp_thresh = threshold for the pp 
%   region_list = txt file with the list of regions selected for analysis
%   (full file path)
%   anat_map = anatomical map (aal, Brodmann - full path)
% Output: 
%   roi_ppmap= 3D matrix w/ regional pp values

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Writen by: Gordana Derado, Ph.D, Emory Univ.     %
% Modified by: Lijun Zhang, Ph.D                   %
% Center for Biomedical Imaging Statistics (CBIS)  %
% Dept. of Biostatistics and Bioinformatics        %
% Emory University                                 %
% Atlanta, GA, 30322                               %
% Email: l.zhang@emory.edu                         %
% http://www.sph.emory.edu/bios/CBIS/about.html    %
% Jan, 2009, Last revision: Jan 25, 2010           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 


G=size(pp.regional,1);  % to get how many regions were analyzed; another way: read in regions list
gray_voxs=[];
for g=1:G
    gray_voxs=[gray_voxs ; glocs(g).roi'];
end

roi_struct=avw_img_read(anat_map);
roi_map=roi_struct.img;

  % this image should be provided by the user, unless data normalized to the standard brain
mri_struct=avw_img_read(mri_fn);  % this should be changed load_nii for nifti images
mri_map=mri_struct.img;

% Following depends on the contrast
% ----------------- Patients versus Controls ------------------------------
voxel_ppmap=zeros(size(mri_map));
voxel_ppmap(brain_locs(gray_voxs))=pp.voxel;

% save as nii